function [OUT]=AveragingOpt(IN,PARAM)
   % Anti-diagonal averaging.
   % Syntax:
   %        [OUT]=AveragingOpt(IN,L1,L2,N1,N2,flag)
   % INPUTS:
   %        IN - Hankel matrix
   %         L - Filter length
   %         N - Dimension of output signal
   %
   % OUTPUT:
   %        OUT - Signal
   %
   % Breno Bahia
%%

   % Preliminares
      N = PARAM.N;
      L = PARAM.L;
      K = PARAM.K;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
      OUT = UnHankel(IN);
      OUT = OUT(:);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%	   

   function OUT = UnHankel(IN)
      
      % Count for averaging
      count = zeros(L(1),K(1),N(2));

      % Allocate memory for lower-level Hankel matrices
      R = zeros(L(1),K(1),N(2));
   
      % Allocate memory for output
   	OUT = zeros(N(1),N(2));
	   
	   % Anti-diagonal averaging (higher level)
      for j=1:L(2)
         for i=1:K(2)

            n=i+j-1;

            count(:,:,n)=count(:,:,n)+ones(L(1),K(1));
            
            StartRow = 1+(j-1)*L(1);
              EndRow = L(1)+(j-1)*L(1);
              
            StartCol = 1+(i-1)*K(1);
              EndCol = K(1)+(i-1)*K(1);
              
            R(:,:,n)=R(:,:,n)+IN(StartRow:EndRow,StartCol:EndCol);
            
         end
      end
      R=R./count;
      
	   % Anti-diagonal averaging (lower level)
      % This allows me to use this code for 1D unHankelization.
	   if N(2)<2
         OUT = AntiDiagAvg(R,N(1));
      else
         for n = 1:N(2)
            OUT(:,n) = AntiDiagAvg(R(:,:,n),N(1));
         end
      end
      
   end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%	   
   function SOUT = AntiDiagAvg(IN,N)

      % Loop bounds   
      [La,Ka]=size(IN);

      % Allocate memory for output
   	SOUT=zeros(N,1);
   	count=zeros(N,1);
      
      % Anti-diagonal averaging
      for i=1:La
      	for j=1:Ka
   			count(i+j-1) = count(i+j-1)+1;					 
   			SOUT(i+j-1) = SOUT(i+j-1)+IN(i,j);	
      	end
      end
      SOUT = SOUT./count;
   end
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%	   
end
