function OUT = BFGDSSAOp(IN,PARAM)
% SSA Operator via Bifactored Gradient Descent
% The rank-reduction operation is done via bifactored regression on UV'.
% Syntax:
%       OUT=BFGDSSAOp(IN,PARAM)
% INPUTS:
%       IN - Monochromatic frequency slice
%       PARAM - Structure containing required parameters
% OUTPUTS:
%        OUT - Filtered frequency slice
%
% Breno Bahia
%% 

   params = PARAM; 


   % Hankel matrix dimensions
   N = size(IN);
   L = floor(N/2)+1;
   K = N-L+1;

   % Set parameters for BFGD

   params.m = prod(L);
   params.n = prod(K);
   params.y = IN;

   
   % Averaging and Hankelization parameters

   Op.L = L;
   Op.N = N;
   Op.K = K;
   Op.flag = 'real';
   
   % Handles for forward (A_id) and adjoint (At_id) operators

    params.A_id  = @(z) AveragingOpt(z,Op);     
    params.At_id = @(z) HankelOpt(reshape(z,N),Op);
   
   % Cost functions

  f = @(u, v) 1/6 * params.alpha^2 * ( 1- ( 1 - (abs(IN(:) - params.A_id(u*v'))./params.alpha).^2 ).^3 );

   f_grad = @(W,x) -(  params.At_id(  W*(IN(:) - params.A_id(x))  )  );


   OUT = params.A_id( (BFGD(f, f_grad, params)) );

   
end
