function [OUT]=FXProcess(IN,Op,PARAM)
   % Apply ND filtering Operator (Op) in frequency-space domain.
   %
   % Syntax:
   %        [OUT]=FXProcess(IN,Op,PARAM) 
   %
   % INPUTS:
   %        IN - Seismic section to be filtered
   %        Op - function handle to filtering operator Op 
   %                  (e.g., Op=@SSAOp, Op=@ImputationOp)
   %        PARAM - Parameters to Op 
   %
   % OUTPUTS:
   %        OUT - Filtered section
   %
   % Breno Bahia
%%

      % Pad for FFT
      dims = size(IN);

      [nt] = dims(1);
      nfft = 2^nextpow2(nt);
      
      % Fourier transform
      INF = fft(IN,nfft,1);
      
      % Allocate memory for OUT in frequency domain
      OUTF = zeros(size(INF));

      % Compute frequency indeces
      [ifmin,ifmax] = FreqInd(PARAM.fmin,PARAM.fmax,PARAM.dt,nfft);

      % Operate on one side of spectrum only
      parfor i=ifmin:ifmax
         % Filtering action through Op
              Temp = Op(squeeze(reshape(INF(i,:),[dims(2:end),1])),PARAM);
         OUTF(i,:) = Temp(:);
      end

      % Symmetries and inverse fft.
      OUTF=fixSym1d(OUTF,nfft);
      OUT= real( ifft(OUTF,[],1) );
      
      % Adjoint of zero-padding is truncation
      OUT=OUT(1:dims(1),:);
      OUT=reshape(OUT,dims);
end
