function [OUT]=HankelOpt(IN,PARAM)
   % Creates Hankel matriz for a given signal.
   % Syntax:
   %        [OUT]=HankelOp(IN,L1,L2,flag);
   %
   % INPUTS:
   %        IN - Signal
   %        L - vector with filter lengths
   %        OUT - Filtered signal
   %
   % Breno Bahia
%%

   % Preliminares
      N = PARAM.N;
      L = PARAM.L;
      K = PARAM.K;

            OUT = GetHankel(IN);

function OUT = GetHankel(IN)
   % This allows me to use this code for 1D Hankelization.
   % If IN is a column vector, make it a row.
   %if N2 == 1
      %IN=transpose(IN);
   %end
   
	% Allocate memory for MBH: Hankel matrix in R^{L1L2...LnxK1K2...Kn}
	OUT = zeros(prod(L),prod(K));
	
   % Fill R with Hankel matrices
   R = zeros(L(1),K(1),N(2));

   % Loop over columns, extract each row.
   for i=1:N(2)
      R(:,:,i)=Hankelization(IN(:,i),L(1));
   end
      
   % Construct MBH
   for j=1:L(2)
      for i=1:K(2)
         n=i+j-1;
         OUT(1+(j-1)*L(1):L(1)+(j-1)*L(1),1+(i-1)*K(1):K(1)+(i-1)*K(1))=R(:,:,n);
      end
   end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%	   
function [SOUT]=Hankelization(IN,local_L)
% Creates Hankel matriz for a given signals.
% Syntax:
%        [OUT]=Hankelization(IN,L)
% INPUTS:
%        IN - Signal
%        L - length of window
% OUTPUTS:
%        OUT - Hankel matrix
%
% Breno Bahia
%%

% 1.0) Get trajectory matrix
   % Signal length
   local_N=length(IN);

   % OUT 2nd dimension
   local_K=local_N-local_L+1;
               
   % Allocate memory for T: Hankel matrix in R^{LxK}
   SOUT=zeros(local_L,local_K);

   % Embed OUT with lagged versions of IN
   for i=1:local_K
	   SOUT(:,i)=IN((1:local_L)+i-1);
   end
   
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%	   
end
