function OUT=SVDSSAOp(IN,PARAM)
   % 2D SSA Operator (P=P_hP_rP_a in the paper).
   % The rank-reduction operation is done via truncated svd (MATLAB svds).
   % Syntax:
   %       [OUT]=SVDSSAOp(IN,PARAM)
   % INPUTS:
   %       IN - Monochromatic frequency slice
   %       PARAM - Structure containing required paramters:
   %               L1/L2 - Filter lengths in 1st and 2nd dimensions
   %               k - Desired rank
   % OUTPUTS:
   %        OUT - Filtered frequency slice
   %
   % Breno Bahia
%% 

   % Signal length
   PARAM.N = size(IN);
   
   % Hankel matrix dimensions
   PARAM.L = floor(PARAM.N/2)+1;
   PARAM.K = PARAM.N-PARAM.L+1;

   % Obtain trajectory matrix through Hankelization
   T=HankelOpt(IN,PARAM);

   % Obtain rank-reduced approximation of T through SVD
   T=RankReduction(T,PARAM.k);

   % Obtain filtered output through anti-diagonal averaging
   OUT=AveragingOpt(T,PARAM);
   
   % Return a long vector
   OUT=OUT(:);
end
