function [OUT,Minval,Maxval,npatch]=SeisPatchlrz(IN,PARAM)
   % Function to patch ND seismic data.
   % Syntax:
   %        [OUT,Mint,Maxt,Minx,Maxx]=SeisPatch2D(IN,dt,it_WL,it_WO,dx,ix_WL,ix_WO,xmin,xmax)
   % INPUTS:
   %        IN - Full seismic section
   %        dt - sampling in time
   %        it_WL - window length in time
   %        it_WO - window overlap in time (give in %)
   %        dx - sampling in space
   %        ix_WL - window length in space
   %        it_WO - window overlap in space (give in %)
   %        xmin - minimum offset to be used in samples
   %        xmax - maximum offset to be used in samples
   %
   % OUTPUTS:
   %        OUT - Patches
   %        Minval - vector with minimum time/space in patches
   %        Maxval - vector with maximum time/space in patches
   % TODO:
   %        - Change INPUTS from this header
   %
   % Note: This function is a translation from the SeismicJulia package.
   %*Credits: B. Bahia, A. Stanton, F. Carozzi, 2017*
%%

      % Get parameters
      [dt,it_WL,it_WO,x1min,x1max,ix1_WL,ix1_WO] = getPatchParam(PARAM,num2str(ndims(IN)));
      
      % Patches dimensions
        nt = size(IN,1);
		nx1=x1max-x1min+1;
		
      % Window overlaps in samples
		it_WO  = round((it_WO*it_WL)/100);
		ix1_WO = round((ix1_WO*ix1_WL)/100);
		
		% Safe-guard for window bigger than data
		if it_WL > nt
			it_WL = nt;
		end

		if ix1_WL > nx1
			ix1_WL = nx1;
		end
		
		tmax = dt*(nt-1);

		% Number of windows in t and x
		 it_NW = floor(nt/(it_WL-it_WO));
		ix1_NW = floor(nx1/(ix1_WL-ix1_WO));
 		
		% Safe-guard to account for ovelarpping samples
		% This assumes data starts from 0 time
		if (dt*(it_NW-1)*(it_WL-it_WO)+dt*(it_WL)) < tmax
			it_NW=it_NW+1;
		end

		if (x1min+(ix1_NW-1)*(ix1_WL-ix1_WO)+ix1_WL) < x1max
			ix1_NW=ix1_NW+1;
		end
		
		% Number of patches

        NW=it_NW*ix1_NW;

		% Preallocate output
		OUT=zeros(it_WL,ix1_WL,NW);

		% Split section into n multipatches
		npatch=0;

		for it_W=1:it_NW 
			% Get starting and ending points of patches
			mint=dt*(it_W-1)*(it_WL-it_WO);
			maxt=mint+dt*(it_WL-1);

			if maxt>=tmax
				maxt=tmax;
			end

			for ix1_W=1:ix1_NW
                minx1=x1min+(ix1_W-1)*(ix1_WL-ix1_WO);
				maxx1=minx1+(ix1_WL-1);

				if  maxx1 >= x1max
                    maxx1 =  x1max;
                end
			    npatch=npatch+1;
				Minval(npatch,:)=[mint minx1]; 
                Maxval(npatch,:)=[maxt maxx1];
            end
        end

       
      % Actual patch extraction
		for ipatch=1:npatch
			temp = SeisWindowPatchlrz(IN,dt,Minval(ipatch,:),Maxval(ipatch,:));
            OUT(1:size(temp,1),1:size(temp,2),ipatch) = temp;
		end
		
		OUT=squeeze(OUT);
end
