function [OUT]=SeisWindowPatchlrz(IN,dt,Minvalue,Maxvalue)
   % Function to extract patches from seismic.
   % Syntax:
   %        [OUT]=SeisWindowPatch(IN,dt,mint,maxt,dx,ixmin,ixmax)
   % INPUTS:
   %        IN - Seismic section
   %        dt - sampling in time
   %        mint - minimum time to be extracted
   %        maxt - maximum time to be extracted
   %        dx - sampling in space
   %        ixmin - minimum space index to be extracted
   %        ixmax - maximum space index to be extracted
   %
   % OUTPUTS:
   %        OUT - Patch
   %
   % Note: Adapted from SeismicJulia package.
   %
   % Credits: AS and FC, 2017.
%%

         [nt,nx]=size(IN);

      
        mint=Minvalue(1);
      ix1min=Minvalue(2);
     
      
        maxt=Maxvalue(1);
      ix1max=Maxvalue(2);
     

      itmin=round(mint/dt)+1;
      itmax=round(maxt/dt)+1;

      if itmin<1
         itmin=1;
      end

      if itmax>nt
         itmax=nt;
      end
      
      if ix1min<1
         ix1min=1;
      end

      if ix1max>nx
         ix1max=nx;
      end
      
      
      F=str2func(class(IN));
      OUT=F(zeros(length(itmin:itmax),length(ix1min:ix1max)));
            
%       OUT=zeros((itmax-itmin+1),(ix1max-ix1min+1));
                
      % Extract samples

      for ix1 = ix1min:ix1max
          for it = itmin:itmax
              OUT(it-itmin+1,ix1-ix1min+1)=IN(it,ix1);              
          end
      end


end
