function [RE,SNR]=quality(Drec,Dtrue)
% quality: Evaluate the quality of the reconstruction. 
%
% Input: Drec is the reconstructed data
%        Dtrue is the true desired
%
% Output: Relative mean squared error X 100
%       : SNR in dBs
%
%
% Notice that to avoid any confusion, I have avoided using the function
% norm provided by Matlab. The program works for any real or complex array as far as
% Drec and Dtrue are of equal size. 
%
% M D Sacchi, December 2020. 

 Norm_of_Dtrue = sum( abs(Dtrue(:)).^2 ) ; 
 Norm_of_Error = sum( abs(Drec(:)-Dtrue(:)).^2)  ; 

 RE  = 100.* Norm_of_Error/Norm_of_Dtrue; 

% DB note: I multiply by 10 because I am using sum of squares. 
%          I multiply by 20 = 2x10 if I use sqrt of sum of squares. 

 SNR = 10.*log10(Norm_of_Dtrue/Norm_of_Error); 

return

